
# Table of Contents

1.  [This module is moving to Vox Pupuli](#orgac56a69)
2.  [Description](#org869f598)
3.  [Usage:](#org8a54846)
    1.  [Using action => set:](#org4eac33b)
        1.  [Initial permissions:](#orgdf9602b)
        2.  [Specified acls:](#org6239a1f)
        3.  [Updated permissions:](#org1ae24f5)
    2.  [Using action => exact:](#orgd688571)
        1.  [Initial permissions:](#orgd169087)
        2.  [Specified acls:](#orga6e6012)
        3.  [Updated permissions:](#org6b2a394)
    3.  [Using action => unset:](#orgee4dc79)
        1.  [Initial permissions:](#orgbc17df6)
        2.  [Specified acls:](#org59a0449)
        3.  [Updated permissions:](#orgb14c606)
    4.  [Using action => purge:](#orgf0bd7b1)
        1.  [Initial permissions:](#orga25a963)
        2.  [Specified acls:](#orgadcb267)
        3.  [Updated permissions:](#org539bf02)
4.  [Notes:](#org780dc57)
    1.  [Conflicts with "file" resource type:](#org300e521)
    2.  [Mask check:](#org1353a88)



<a id="orgac56a69"></a>

# This module is moving to Vox Pupuli

This module has been donated to Vox Pupuli and can be found at <https://github.com/voxpupuli/puppet-posix_acl>


<a id="org869f598"></a>

# Description

This plugin module provides a way to set POSIX 1.e (and other standards) file ACLs via Puppet.


<a id="org8a54846"></a>

# Usage:

-   the `posix_acl` resource `title` is used as the path specifier.
-   ACLs are specified in the `permission` property as an array of strings in the same format as is used for `setfacl`.
-   the `action` parameter can be one of `set`, `exact`, `unset` or `purge`. These are described in detail below.
-   the `provider` parameter allows a choice of filesystem ACL provider. Currently only POSIX 1.e is implemented.
-   the `recursive` parameter allows you to apply the ACLs to all files under the specified path.
    
        posix_acl { "/var/log/httpd":
            action     => set,
            permission => [
                           "user::rwx",
                           "group::---",
                           "mask::r-x",
                           "other::---",
                           "group:logview:r-x",
                           "default:user::rwx",
                           "default:group::---",
                           "default:mask::rwx",
                           "default:other::---",
                           "default:group:logview:r-x",
                           ],
            provider   => posixacl,
            require    => [
                           Group["logview"],
                           Package["httpd"],
                           Mount["/var"],
                           ],
            recursive  => false,
        }


<a id="org4eac33b"></a>

## Using action => set:

The `set` option for the `action` parameter allows you to specify a minimal set of ACLs which will be guaranteed by Puppet. ACLs applied to the path which do not match those specified in the `permission` property will remain unchanged.


<a id="orgdf9602b"></a>

### Initial permissions:

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    group:webadmin:r-x
    group:httpadmin:rwx


<a id="org6239a1f"></a>

### Specified acls:

    permission  => [
      'user::rwx',
      'group::r-x',
      'other::r-x',
      'mask::rwx',
      'group:webadmin:rwx',
      'user:apache:rwx',
    ],


<a id="org1ae24f5"></a>

### Updated permissions:

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    user:apache:rwx
    group:webadmin:rwx
    group:httpadmin:rwx


<a id="orgd688571"></a>

## Using action => exact:

The `exact` option for the `action` parameter will specify the exact set of ACLs guaranteed and enforced by Puppet. ACLs applied to the path which do not match those specified in the `permission` property will be removed.


<a id="orgd169087"></a>

### Initial permissions:

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    group:webadmin:r-x
    group:httpadmin:rwx


<a id="orga6e6012"></a>

### Specified acls:

    permission  => [
      'user::rwx',
      'group::r-x',
      'other::r-x',
      'mask::rwx',
      'group:webadmin:r--',
      'user:apache:rwx',
    ],


<a id="org6b2a394"></a>

### Updated permissions:

-   group:httpadmin permission is removed
-   user:apache permission is added
-   group:webadmin permission is updated

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    group:webadmin:r--
    user:apache:rwx


<a id="orgee4dc79"></a>

## Using action => unset:

The `unset` option for the `action` parameter will specify the set of ACLs guaranteed by Puppet to NOT be applied to the path. ACLs applied to the path which match those specified in the `permission` property will be removed. ACLs applied to the path which do not match those specified in the `permission` property will remain unchanged.


<a id="orgbc17df6"></a>

### Initial permissions:

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    group:webadmin:r-x
    group:httpadmin:rwx


<a id="org59a0449"></a>

### Specified acls:

    permission  => [
      'user::rwx',
      'group::r-x',
      'other::r-x',
      'mask::rwx',
      'group:webadmin:r--',
      'user:apache:rwx',
    ],


<a id="orgb14c606"></a>

### Updated permissions:

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    group:httpadmin:rwx


<a id="orgf0bd7b1"></a>

## Using action => purge:

The `purge` option for the `action` parameter will cause Puppet to remove any file ACLs applied to the path.

NOTE: Although the `permission` property is unused for this action, it needs to have a valid ACL value for the action to work. This is a known issue. 


<a id="orga25a963"></a>

### Initial permissions:

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x
    mask::rwx
    group:webadmin:r-x
    group:httpadmin:rwx


<a id="orgadcb267"></a>

### Specified acls:

See above

    permission  => [
      'user::rwx',
      'group::r-x',
      'other::r-x',
      'mask::rwx',
      'group:webadmin:r--',
      'user:apache:rwx',
    ],


<a id="org539bf02"></a>

### Updated permissions:

-   All file ACLs are removed

    # file /var/www/site1
    user::rwx
    group::r-x
    other::r-x


<a id="org780dc57"></a>

# Notes:


<a id="org300e521"></a>

## Conflicts with "file" resource type:

If the path being modified is managed via the `File` resource type, the path's mode bits must match the value specified in the `permission` property of the ACL


<a id="org1353a88"></a>

## Mask check:

The ACL setter doesn't recalculate the rights mask based on the user/group ACLs specified, so it is possible to specify ACLs on a file for which a more restrictive set of rights is enforced, known as "effective rights". For example, with these `permission` parameters on a file `test`:

    permission  => [
      'user::rw-',
      'group::---',
      'mask::r--',
      'other::---',
      'user:apache:rwx',
      'group:root:r-x',
      'group:admin:rwx',
    ],

The output of `getfacl test` reveals a more restrictive set of effective rights, which might not be what was expected:

    # file: test
    # owner: root
    # group: root
    user::rw-
    group::---
    other::---
    mask::r--
    user:apache:rwx                 #effective:r--
    group:root:r-x                  #effective:r--
    group:admin:rwx                 #effective:r--

